@@ -1,11 +1,37 @@
+from enum import IntEnum, Enum
 from typing import Optional
+
+from PIL.Image import Image
 from pydantic import BaseModel
 
-from sps_parser.utils import Parseable
+from sps_parser.converters import rgb_as_hex
 
 DEFAULT_MAGIC_COLOR = "4444aa"
 
 
+class Pixel(Enum):
+    RACE = (0, 0)
+    TAIL_LENGTH = (1, 0)
+    GENDER = (2, 0)
+    SIZE = (3, 0)
+
+    MAGIC_COLOR = (0, 1)
+    WEARABLE = (1, 1)
+
+
+class Parseable(IntEnum):
+    _DEFAULT: int
+
+    @classmethod
+    def get(cls, image: Image, pixel: Pixel):
+        color = image.getpixel(pixel.value)
+        converted = rgb_as_hex(color)
+        try:
+            return cls(converted)
+        except ValueError:
+            return cls._DEFAULT
+
+
 class SkinSize(Parseable):
     NORMAL = 0
     TALL = 0x534b76
@@ -53,15 +79,13 @@ class PonyGender(Parseable):
     _DEFAULT = MARE
 
 
-class Wearable(Parseable):
+class Wearable(IntEnum):
     NONE = 0
     MUFFIN = 0x32
     HAT = 0x64
     SADDLE_BAGS = 0xc8
     STETSON = 0xfa
 
-    _DEFAULT = NONE
-
 
 class SkinMetadata(BaseModel):
     size: SkinSize = SkinSize.NORMAL
